@@ -25,3 +25,8 @@
 #define TOTEM_OPTION_CONTROLS_HIDDEN	"--nocontrols"
 #define TOTEM_OPTION_HREF		"--href"
 #define TOTEM_OPTION_TARGET		"--target"
+#define TOTEM_OPTION_HIDDEN		"--hidden"
+#define TOTEM_OPTION_MIMETYPE		"--mimetype"
+#define TOTEM_OPTION_PLAYLIST		"--playlist"
+#define TOTEM_OPTION_REPEAT		"--repeat"
+#define TOTEM_OPTION_NOAUTOSTART	"--noautostart"
